aboutsummaryrefslogtreecommitdiffstats
path: root/vncviewer/CConn.cxx
diff options
context:
space:
mode:
authorPierre Ossman <ossman@cendio.se>2018-06-20 07:03:10 +0200
committerPierre Ossman <ossman@cendio.se>2018-11-01 16:11:42 +0100
commit2affd7753274ddf3b93505f0ae26af3c45aa3fec (patch)
treec5b54568a87386f30221dd5e7f6771ac6ced44db /vncviewer/CConn.cxx
parent2fae5cf0655811b818108df239ebcbe3ea79cee3 (diff)
downloadtigervnc-2affd7753274ddf3b93505f0ae26af3c45aa3fec.tar.gz
tigervnc-2affd7753274ddf3b93505f0ae26af3c45aa3fec.zip
Stop requiring CConnection::serverInit() to be overridden
Add an explicit callback for subclasses to do their startup in. This makes it easier to do proper ordering, and avoids mistakes.
Diffstat (limited to 'vncviewer/CConn.cxx')
-rw-r--r--vncviewer/CConn.cxx6
1 files changed, 2 insertions, 4 deletions
diff --git a/vncviewer/CConn.cxx b/vncviewer/CConn.cxx
index fe8e6cf5..23257ee6 100644
--- a/vncviewer/CConn.cxx
+++ b/vncviewer/CConn.cxx
@@ -308,13 +308,11 @@ void CConn::socketEvent(FL_SOCKET fd, void *data)
////////////////////// CConnection callback methods //////////////////////
// serverInit() is called when the serverInit message has been received. At
// this point we create the desktop window and display it. We also tell the
// server the pixel format and encodings to use and request the first update.
-void CConn::serverInit()
+void CConn::initDone()
{
- CConnection::serverInit();
-
// If using AutoSelect with old servers, start in FullColor
// mode. See comment in autoSelectFormatAndEncoding.
if (server.beforeVersion(3, 8) && autoSelect)
@@ -308,13 +308,11 @@ void CConn::socketEvent(FL_SOCKET fd, void *data)
////////////////////// CConnection callback methods //////////////////////
-// serverInit() is called when the serverInit message has been received. At
+// initDone() is called when the serverInit message has been received. At
// this point we create the desktop window and display it. We also tell the
// server the pixel format and encodings to use and request the first update.